package othello.models;

/**
 * Les prfrences du jeux.
 * @author Jean-Franois Berdjugin
 * Les prfrences sont stockes comme suit : 
 * Pour les joueur 0 humain, 1-3 computer.
 * Pour la musique de fond et les sons des boolens 
 */
public class PreferenceModel {
	/**
	 * Le premier joueur 0 humain 1-3 computer
	 */
	private int firstPlayer;
	/**
	 * Le deuxime joueur  0 humain 1-3 computer
	 */
	private int secondPlayer;
	/**
	 * true si musique de fond et false sinon
	 */
	private boolean backgroundMusic;
	/**
	 * true si sons du jeu et false sinon
	 */
	private boolean sounds;
	
	/**
	 * Le premier et le second joueur sont jous par des humains,
	 * la musique de fond est dsactive, les sons sont actifs. 
	 */
	public PreferenceModel()
	{
		this.firstPlayer=0;
		this.secondPlayer=0;
		this.backgroundMusic=false;
		this.sounds=true;
	}

	/**
	 * Permet de connatre le premier joueur
	 * @return 0 humain 1-3 computer
	 */
	public int getFirstPlayer() {
		return firstPlayer;
	}

	/**
	 * Permet de choisir le premier joueur
	 * @param firstPlayer 0 humain 1-3 computer
	 */
	public void setFirstPlayer(int firstPlayer) {
		if (firstPlayer<0 || firstPlayer>3)
			firstPlayer=0;
		this.firstPlayer = firstPlayer;
	}
	/**
	 * Permet de connatre le second joueur
	 * @return 0 humain 1-3 computer
	 */
	public int getSecondPlayer() {
		return secondPlayer;
	}
	/**
	 * Permet de choisir le second joueur
	 * @param secondPlayer 0 humain 1-3 computer
	 */
	public void setSecondPlayer(int secondPlayer) {
		if (secondPlayer<0 || secondPlayer>3)
			secondPlayer=0;
		this.secondPlayer = secondPlayer;
	}

	/**
	 * Permet de savoir si la musique de fond est active
	 * @return true si musique false sinon
	 */
	public boolean isBackgroundMusic() {
		return backgroundMusic;
	}

	/**
	 * Permet d'activer ou de dsactiver la musique de fond
	 * @param backgroundMusic true active, false non active
	 */
	public void setBackgroundMusic(boolean backgroundMusic) {
		this.backgroundMusic = backgroundMusic;
	}
	/**
	 * Permet de savoir si les sons sont actifs
	 * @return true si sons actifs false sinon
	 */
	public boolean isSounds() {
		return sounds;
	}
	/**
	 * Permet d'activer ou de dsactiver les sons
	 * @param sounds backgroundMusic true active, false non active
	 */
	public void setSounds(boolean sounds) {
		this.sounds = sounds;
	}

	
}
