package othello.views;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dialog;
import java.awt.FlowLayout;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.net.URL;
import javax.imageio.ImageIO;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import othello.controlers.Controler;
import othello.models.GameModel;


/**
 * La vue de fin de partie.
 * @author Jean-Franois Berdjugin
 * La vue doit connatre le modle du jeux pour afficher le nombre de pions blancs et noirs. 
 * Elle doit aussi connatre le contrleur pour quitter le jeu ou relancer une nouvelle partie.  
 */
public class EndGameView extends JDialog implements ActionListener {
	/**
	 * 
	 */
	private static final long serialVersionUID = 4442379950416472335L;
	/**
	 * Le modle du jeu
	 */
	private GameModel model;
	/**
	 * Le controleur
	 */
	private Controler controler;
	/**
	 * L'image du pion blanc utilise pour la victoire
	 */
	private BufferedImage blackPown;
	/**
	 * L'image du pion noir utilise pour la victoire
	 */
	private BufferedImage whitePown;
	/**
	 * L'image de l'icone
	 */
	private BufferedImage endGame;
	/**
	 * L'image de l'galit
	 */
	private BufferedImage deuce;
	/**
	 * Le bouton qui relance une nouvelle partie
	 */
	private JButton buttonYes;
	/**
	 * Le bouton qui permet de quitter le jeu
	 */
	private JButton buttonNo;

	/**
	 * Le label qui indique le vainqueur
	 */
	private JLabel labelRes;
	/**
	 * Le label qui contient l'icone du vainqueur ou de l'galit
	 */
	private JLabel labelIconRes;


	/**
	 * Construit une bote de dialogue modale rattache  son parent.
	 * @param model le modle du jeu
	 * @param parent la fentre parent
	 * @param controler le controleur du jeu
	 */
	public EndGameView(GameModel model, Window parent, Controler controler)
	{
		super(parent, "Nouvelle Patie ?", Dialog.ModalityType.APPLICATION_MODAL);
		this.setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
		this.model = model;
		this.controler = controler;
		URL url = null;
		url = this.getClass().getClassLoader().getResource("ressources/icon/black_pawn.png");
		try {
			blackPown = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		url = this.getClass().getClassLoader().getResource("ressources/icon/white_pawn.png");
		try {
			whitePown = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		url = this.getClass().getClassLoader().getResource("ressources/icon/endGame.png");
		try {
			endGame = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		url = this.getClass().getClassLoader().getResource("ressources/icon/deuce.png");
		try {
			deuce = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		this.setIconImage(endGame);

		ImageIcon iconRes;
		iconRes = new ImageIcon();
		String res;
		int b,w;
		w= this.model.getSecondPlayerCount();
		b= this.model.getFirstPlayerCount();

		if (w == b)
		{
			iconRes.setImage(deuce);
			res = "Egalit";
		}
		else
			if (w > b)
			{
				iconRes.setImage(whitePown);
				res = "Les blancs gagnent";
			}
			else
			{
				iconRes.setImage(blackPown);
				res = "Les noirs gagnent";
			}

		this.setLayout(new BorderLayout());
		JPanel panelUp = new JPanel(new FlowLayout());
		panelUp.setBackground(Color.gray);

		JPanel panelCenter = new JPanel(new FlowLayout());
		panelCenter.setBackground(Color.gray);

		JPanel panelDown = new JPanel(new FlowLayout());
		panelDown.setBackground(Color.gray);
		this.buttonNo = new JButton("Non");
		this.buttonNo.setBackground(Color.darkGray);
		this.buttonNo.setForeground(Color.red);

		this.buttonYes = new JButton("Oui");
		this.buttonYes.setBackground(Color.darkGray);
		this.buttonYes.setForeground(Color.red);

		labelRes = new JLabel(res);
		panelUp.add(labelRes);
		labelIconRes = new JLabel(iconRes);
		panelCenter.add(labelIconRes);
		panelDown.add(new JLabel("Souhaitez vous une nouvelle partie ?"));
		panelDown.add(buttonYes);
		panelDown.add(buttonNo);
		this.add(panelUp,BorderLayout.NORTH);
		this.add(panelCenter,BorderLayout.CENTER);
		this.add(panelDown,BorderLayout.SOUTH);

		this.buttonNo.addActionListener(this);
		this.buttonYes.addActionListener(this);
		this.pack();
	}

	/**
	 * Permet de mettre  jour le label et l'icone du rsultat en fonction du vainqueur.
	 */
	public void update()
	{
		String res;
		ImageIcon iconRes;
		iconRes = new ImageIcon();
		int b,w;
		w= this.model.getSecondPlayerCount();
		b= this.model.getFirstPlayerCount();

		if (w == b)
		{
			iconRes.setImage(deuce);
			res = "Egalit";
		}
		else
			if (w > b)
			{
				iconRes.setImage(whitePown);
				res = "Les blancs gagnent";
			}
			else
			{
				iconRes.setImage(blackPown);
				res = "Les noirs gagnent";
			}
		labelRes.setText(res);
		labelIconRes.setIcon(iconRes);

	}
	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		Object object = e.getSource();

		if (object.equals(buttonNo))
		{
			this.setVisible(false);
			this.controler.quitter();

		}

		else
			if (object.equals(buttonYes))
			{
				this.setVisible(false);
				this.controler.nouvellePartie();
			}	
	}



}
