package othello.views;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.TexturePaint;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.net.URL;

import javax.imageio.ImageIO;
import javax.swing.JPanel;

import othello.controlers.Controler;
import othello.models.GameModel;

/**
 * Le paneau de jeu, il permet l'affichage du plateau de jeu.
 * @author Jean-Franois Berdjugin
 *Le plateau de jeu doit connatre le contrleur pour indiquer quel coup jouer. 
 */
public class GameBoard extends JPanel implements MouseListener{
	/**
	 * 
	 */
	private static final long serialVersionUID = 5961223344359135685L;
	/**
	 * Le controleur du jeu
	 */
	private Controler controler;
	/**
	 * Le modle du jeu
	 */
	private GameModel model;
	/**
	 * La taille du plateau
	 */
	private final static int SIZE = 600;
	/**
	 * La marge externe
	 */
	private final static int MARGIN = 100;
	/**
	 * La marge des pions
	 */
	private final static int POWN_MAGIN = 5;
	/**
	 * L'image d'un pion du premier joueur
	 */
	private BufferedImage blackPown;
	/**
	 * L'image d'un pion du second joueur
	 */
	private BufferedImage whitePown;
	/**
	 * L'image du fond
	 */
	private BufferedImage background;
	/**
	 * mise  true elle affiche les coordonnes des cases
	 */
	private boolean debug;


	/**
	 * Construit un plateau de jeu
	 * @param model le modle du jeu
	 * @param controler le contrleur du jeu
	 */
	public GameBoard(GameModel model, Controler controler)
	{
		this.model = model;
		this.controler = controler;

		this.setSize(SIZE,SIZE);
		this.setPreferredSize(new Dimension(SIZE,SIZE));
		//this.setBackground(Color.LIGHT_GRAY);
		URL url = null;
		url = this.getClass().getClassLoader().getResource("ressources/icon/black_pawn.png");
		try {
			blackPown = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		url = this.getClass().getClassLoader().getResource("ressources/icon/white_pawn.png");
		try {
			whitePown = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		url = this.getClass().getClassLoader().getResource("ressources/icon/background.png");
		try {
			background = ImageIO.read(url);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		this.addMouseListener(this);
		this.debug = false;
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paint(java.awt.Graphics)
	 */
	@Override
	public void paint(Graphics arg0) {
		// TODO Auto-generated method stub
		super.paint(arg0);
		Graphics2D graphics2d = (Graphics2D) arg0;
		//graphics2d.drawRect(100, 100, size-200, size-200);
		int pos = MARGIN;
		int larg = (SIZE - 2 * MARGIN) /8;
		graphics2d.setPaint(new TexturePaint(background, new Rectangle(0,0,SIZE,SIZE)));
		graphics2d.fillRect(0,0,SIZE,SIZE);
		graphics2d.setColor(Color.BLACK);
		for (int i = 0; i < 9; i++)
		{
			graphics2d.drawLine(pos, MARGIN, pos, SIZE -  MARGIN);
			graphics2d.drawLine(MARGIN, pos, SIZE -  MARGIN,pos);
			pos = pos + larg;

		}

		pos = MARGIN + larg/2;
		char c = 'a';
		int[][] board = model.getBoard();
		for (int i =0; i < 8; i++)
		{
			graphics2d.drawString(String.valueOf(c), pos, MARGIN-10);
			graphics2d.drawString(String.valueOf(c), pos, SIZE-MARGIN+10);
			graphics2d.drawString(String.valueOf(i+1), MARGIN-10, pos);
			graphics2d.drawString(String.valueOf(i+1), SIZE-MARGIN+10, pos);
			c =(char) (c + 1);
			pos = pos + larg;
		}
		BufferedImage pown;
		for (int x=0; x <8; x++)
			for (int y=0; y < 8; y++)
			{
				if (board[x][y]==1 || board[x][y]==-1)
				{

					if (board[x][y]==-1)
					{
						pown = whitePown;
					}	
					else
					{
						pown = blackPown;
					}
					graphics2d.drawImage(pown, MARGIN + x * larg+POWN_MAGIN, MARGIN+ y * larg+POWN_MAGIN, 
							larg-POWN_MAGIN*2, larg-POWN_MAGIN*2, this);

				}
				if (debug)
					graphics2d.drawString("("+x+","+y+")="+board[x][y], MARGIN + x * larg, MARGIN+ y * larg+larg/2);
			}	

		if (model.getCurrentUser() == -1)
			pown = whitePown;
		else
			pown = blackPown;
		graphics2d.drawImage(pown, 0, SIZE - larg,larg-POWN_MAGIN*2, larg-POWN_MAGIN*2, this);

		pown = blackPown;
		graphics2d.drawImage(pown, SIZE-larg*4, SIZE - larg,larg-POWN_MAGIN*2, larg-POWN_MAGIN*2, this);
		graphics2d.drawString(String.valueOf(this.model.getFirstPlayerCount()), SIZE-larg*3, SIZE - larg/2);
		pown = whitePown;
		graphics2d.drawImage(pown, SIZE-larg*2, SIZE - larg,larg-POWN_MAGIN*2, larg-POWN_MAGIN*2, this);
		graphics2d.drawString(String.valueOf(this.model.getSecondPlayerCount()), SIZE-larg, SIZE - larg/2);
	}

	@Override
	public void mouseClicked(MouseEvent e) {

	}

	@Override
	public void mouseEntered(MouseEvent e) {
		// TODO Auto-generated method stub

	}

	@Override
	public void mouseExited(MouseEvent e) {
		// TODO Auto-generated method stub

	}

	/* 
	 * (non-Javadoc)
	 * @see java.awt.event.MouseListener#mousePressed(java.awt.event.MouseEvent)
	 */
	@Override
	public void mousePressed(MouseEvent e) {
		int x = e.getX();
		int y = e.getY();
		x = ((x-MARGIN)*8)/(SIZE - 2 * MARGIN);
		y = ((y-MARGIN)*8)/(SIZE - 2 * MARGIN);
		if (x>=0 && x <8 && y>=0 && y <8)
			controler.playXY(x,y);

	}

	@Override
	public void mouseReleased(MouseEvent e) {
		// TODO Auto-generated method stub

	}

}
