package othello.views;

import java.applet.Applet;
import java.applet.AudioClip;
import java.net.URL;



/**
 * La vue qui permet de jouer un son ou une musique.
 * @author Jean-Franois Berdjugin
 *
 */
public class SoundsView {
	/**
	 * La musique de fond.
	 */
	private AudioClip backgroundAudioClip;
	/**
	 * La musique de fin.
	 */
	private AudioClip endAudioClip;
	/**
	 * Le son associ  un jeu.
	 */
	private AudioClip playAudioClip;

	/**
	 * Permet de savoir si la musique de fond est en cours de lecture.
	 */
	private boolean isPlayingBackgroundAudioClip;
	/**
	 * Permet de savoir si la musique de fin est en cours de lecture.
	 */
	private boolean isPlayingEndAudioClip;

	/**
	 * Le constructeur
	 */
	public SoundsView()
	{
		URL url;
		url = this.getClass().getClassLoader().getResource("ressources/sound/background_music.mid");
		this.backgroundAudioClip=Applet.newAudioClip(url);
		url = this.getClass().getClassLoader().getResource("ressources/sound/end_music.wav");
		this.endAudioClip=Applet.newAudioClip(url);
		url = this.getClass().getClassLoader().getResource("ressources/sound/play_music.wav");
		this.playAudioClip=Applet.newAudioClip(url);
		this.isPlayingBackgroundAudioClip = false;
		this.isPlayingEndAudioClip = false;

	}

	/**
	 * Permet de jouer la musique de fond en boucle.
	 */
	public void playMusic()
	{
		if (!isPlayingBackgroundAudioClip)
		{
			this.backgroundAudioClip.loop();
			this.isPlayingBackgroundAudioClip=true;
		}
	}

	/**
	 * Permet d'arrter la musique de fond.
	 */
	public void stopMusic()
	{
		this.backgroundAudioClip.stop();
		this.isPlayingBackgroundAudioClip=false;
	}

	/**
	 * Permet de jouer la musique de fin en boucle.
	 */
	public void playEndMusic()
	{
		if (!this.isPlayingEndAudioClip)
		{
		this.endAudioClip.loop();
		this.isPlayingEndAudioClip = false;
		}
	}

	/**
	 * Permet d'arrter la musique de fin.
	 */
	public void stopEndMusic()
	{

			this.endAudioClip.stop();
			this.isPlayingEndAudioClip = false;
	}

	/**
	 * Permet de jouer le son associ  un coup.
	 */
	public void playPlay()
	{
		if (this.playAudioClip !=null)
		this.playAudioClip.play();
	}


}
